@@ -258,7 +258,7 @@ pmcid_regexp = re.compile(r"PMC\d+$", flags=re.I)
 pmid_regexp = re.compile(r"(pmid:)?(\d+)$", flags=re.I)
 """PubMed ID regular expression."""
 
-ark_suffix_regexp = re.compile(r"ark:/\d+/.+$")
+ark_suffix_regexp = re.compile(r"ark:/[0-9bcdfghjkmnpqrstvwxz]+/.+$")
 """See http://en.wikipedia.org/wiki/Archival_Resource_Key and
        https://confluence.ucop.edu/display/Curation/ARK."""
 
@@ -334,14 +334,14 @@ geo_regexp = re.compile(r"G(PL|SM|SE|DS)\d+$")
 See https://www.ncbi.nlm.nih.gov/geo/info/overview.html#org
 """
 
-arrayexpress_array_regexp = re.compile("A-({codes})-\d+$".format(
+arrayexpress_array_regexp = re.compile(r"A-({codes})-\d+$".format(
     codes="|".join(ARRAYEXPRESS_CODES)))
 """ArrayExpress array accession.
 
 See https://www.ebi.ac.uk/arrayexpress/help/accession_codes.html
 """
 
-arrayexpress_experiment_regexp = re.compile("E-({codes})-\d+$".format(
+arrayexpress_experiment_regexp = re.compile(r"E-({codes})-\d+$".format(
     codes="|".join(ARRAYEXPRESS_CODES)))
 """ArrayExpress array accession.
 
